.. _reporting_bugs:

Reporting bugs
===============

We use GitHub issues to track all bugs and feature requests; feel free
to open an issue if you have found a bug or wish to see a feature
implemented.

It is recommended to check that your issue complies with the following
rules before submitting:

-  Verify that your issue is not being currently addressed by other
   `issues <https://github.com/aeon-toolkit/aeon/issues>`__
   or `pull
   requests <https://github.com/aeon-toolkit/aeon/pulls>`__.
-  Please ensure all code snippets and error messages are formatted in
   appropriate code blocks. See `Creating and highlighting code
   blocks <https://help.github.com/articles/creating-and-highlighting-code-blocks>`__.
-  Please be specific about what estimators and/or functions are
   involved and the shape of the data, as appropriate; please include a
   `reproducible <https://stackoverflow.com/help/mcve>`__ code snippet
   or link to a `gist <https://gist.github.com>`__. If an exception is
   raised, please provide the traceback.

.. note::

   To find out more about how to take part in aeon’s community, check out our `governance
   guidelines <https://www.aeon-toolkit.org/en/latest/governance.html>`__.
